==> nextcloud-desktop_2.5.1.orig.tar.gz: desktop-2.5.1/src/gui/wizard/owncloudshibbolethcredspage.h <==
/*
 * Copyright (C) by Krzesimir Nowak <krzesimir@endocode.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */

#ifndef MIRALL_OWNCLOUD_SHIBBOLETH_CREDS_PAGE_H
#define MIRALL_OWNCLOUD_SHIBBOLETH_CREDS_PAGE_H

#include <QList>
#include <QMap>
#include <QNetworkCookie>
#include <QUrl>
#include <QPointer>

#include "wizard/abstractcredswizardpage.h"
#include "accountfwd.h"

namespace OCC {

class ShibbolethWebView;

/**
 * @brief The OwncloudShibbolethCredsPage class
 * @ingroup gui
 */
class OwncloudShibbolethCredsPage : public AbstractCredentialsWizardPage
{
    Q_OBJECT
public:
    OwncloudShibbolethCredsPage();

    AbstractCredentials *getCredentials() const override;

    void initializePage() override;
    int nextId() const override;
    void setConnected();

Q_SIGNALS:
    void connectToOCUrl(const QString &);

public Q_SLOTS:
    void setVisible(bool visible) override;

private Q_SLOTS:
    void slotShibbolethCookieReceived(const QNetworkCookie &);
    void slotBrowserRejected();

private:
    void setupBrowser();

    QPointer<ShibbolethWebView> _browser;
    bool _afterInitialSetup;
    QNetworkCookie _cookie;
};

} // namespace OCC

#endif

==> nextcloud-desktop_3.1.1.orig.tar.gz: desktop-3.1.1/src/gui/wizard/owncloudshibbolethcredspage.h <==
/*
 * Copyright (C) by Krzesimir Nowak <krzesimir@endocode.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */

#ifndef MIRALL_OWNCLOUD_SHIBBOLETH_CREDS_PAGE_H
#define MIRALL_OWNCLOUD_SHIBBOLETH_CREDS_PAGE_H

#include <QList>
#include <QMap>
#include <QNetworkCookie>
#include <QUrl>
#include <QPointer>

#include "wizard/abstractcredswizardpage.h"
#include "accountfwd.h"

namespace OCC {

class ShibbolethWebView;

/**
 * @brief The OwncloudShibbolethCredsPage class
 * @ingroup gui
 */
class OwncloudShibbolethCredsPage : public AbstractCredentialsWizardPage
{
    Q_OBJECT
public:
    OwncloudShibbolethCredsPage();

    AbstractCredentials *getCredentials() const override;

    void initializePage() override;
    int nextId() const override;
    void setConnected();

Q_SIGNALS:
    void connectToOCUrl(const QString &);

public Q_SLOTS:
    void setVisible(bool visible) override;

private Q_SLOTS:
    void slotShibbolethCookieReceived(const QNetworkCookie &);
    void slotBrowserRejected();

private:
    void setupBrowser();

    QPointer<ShibbolethWebView> _browser;
    bool _afterInitialSetup = false;
    QNetworkCookie _cookie;
};

} // namespace OCC

#endif
